Overview
========

ScrapyX is a subcommand for scrapy enables you to easily convert your scrapy project to a simple, 
distributed and high-performance crawling platform, for more info go there: https://github.com/alash3al/scrapy-x

Install
=======

The quick way::

    pip install scrapy-x


